Crate aws_sdk_rdsdata[][src]

Amazon RDS Data Service

Amazon RDS provides an HTTP endpoint to run SQL statements on an Amazon Aurora Serverless DB cluster. To run these statements, you work with the Data Service API.

For more information about the Data Service API, see Using the Data API for Aurora Serverless in the Amazon Aurora User Guide.

Re-exports

pub use config::Config;
pub use client::Client;

Modules

Client and fluent builders for calling the service.

Configuration for the service.

Errors that can occur when calling the service.

Input structures for operations.

Data structures used by operation inputs/outputs.

All operations that this crate can perform.

Output structures for operations.

Structs

App name that can be configured with an AWS SDK client to become part of the user agent string.

Binary Blob Type

Stream of binary data

AWS SDK Credentials

DateTime in time.

API Endpoint

The region to send requests to.

Retry configuration for requests.

Enums

All possible error types for this service.

Failed SDK Result

Statics

Crate version number.