Struct aws_sdk_rdsdata::client::fluent_builders::BatchExecuteStatement[][src]

pub struct BatchExecuteStatement<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to BatchExecuteStatement.

Runs a batch SQL statement over an array of data.

You can run bulk update and insert operations for multiple records using a DML statement with different parameter sets. Bulk operations can provide a significant performance improvement over individual insert and update operations.

If a call isn't part of a transaction because it doesn't include the transactionID parameter, changes that result from the call are committed automatically.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.

The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.

The name or ARN of the secret that enables access to the DB cluster.

The name or ARN of the secret that enables access to the DB cluster.

The SQL statement to run.

The SQL statement to run.

The name of the database.

The name of the database.

The name of the database schema.

The name of the database schema.

Appends an item to parameterSets.

To override the contents of this collection use set_parameter_sets.

The parameter set for the batch operation.

The SQL statement is executed as many times as the number of parameter sets provided. To execute a SQL statement with no parameters, use one of the following options:

  • Specify one or more empty parameter sets.

  • Use the ExecuteStatement operation instead of the BatchExecuteStatement operation.

Array parameters are not supported.

The parameter set for the batch operation.

The SQL statement is executed as many times as the number of parameter sets provided. To execute a SQL statement with no parameters, use one of the following options:

  • Specify one or more empty parameter sets.

  • Use the ExecuteStatement operation instead of the BatchExecuteStatement operation.

Array parameters are not supported.

The identifier of a transaction that was started by using the BeginTransaction operation. Specify the transaction ID of the transaction that you want to include the SQL statement in.

If the SQL statement is not part of a transaction, don't set this parameter.

The identifier of a transaction that was started by using the BeginTransaction operation. Specify the transaction ID of the transaction that you want to include the SQL statement in.

If the SQL statement is not part of a transaction, don't set this parameter.