Struct aws_sdk_rdsdata::client::fluent_builders::BeginTransaction[][src]

pub struct BeginTransaction<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to BeginTransaction.

Starts a SQL transaction.

A transaction can run for a maximum of 24 hours. A transaction is terminated and rolled back automatically after 24 hours.

A transaction times out if no calls use its transaction ID in three minutes. If a transaction times out before it's committed, it's rolled back automatically.

DDL statements inside a transaction cause an implicit commit. We recommend that you run each DDL statement in a separate ExecuteStatement call with continueAfterTimeout enabled.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.

The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.

The name or ARN of the secret that enables access to the DB cluster.

The name or ARN of the secret that enables access to the DB cluster.

The name of the database.

The name of the database.

The name of the database schema.

The name of the database schema.