Struct aws_sdk_rdsdata::client::fluent_builders::CommitTransaction [−][src]
pub struct CommitTransaction<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to CommitTransaction.
Ends a SQL transaction started with the BeginTransaction operation and
commits the changes.
Implementations
impl<C, M, R> CommitTransaction<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> CommitTransaction<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<CommitTransactionOutput, SdkError<CommitTransactionError>> where
R::Policy: SmithyRetryPolicy<CommitTransactionInputOperationOutputAlias, CommitTransactionOutput, CommitTransactionError, CommitTransactionInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<CommitTransactionOutput, SdkError<CommitTransactionError>> where
R::Policy: SmithyRetryPolicy<CommitTransactionInputOperationOutputAlias, CommitTransactionOutput, CommitTransactionError, CommitTransactionInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The name or ARN of the secret that enables access to the DB cluster.
The name or ARN of the secret that enables access to the DB cluster.
The identifier of the transaction to end and commit.
The identifier of the transaction to end and commit.