Struct aws_sdk_rdsdata::client::fluent_builders::ExecuteStatement[][src]

pub struct ExecuteStatement<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to ExecuteStatement.

Runs a SQL statement against a database.

If a call isn't part of a transaction because it doesn't include the transactionID parameter, changes that result from the call are committed automatically.

The response size limit is 1 MB. If the call returns more than 1 MB of response data, the call is terminated.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.

The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.

The name or ARN of the secret that enables access to the DB cluster.

The name or ARN of the secret that enables access to the DB cluster.

The SQL statement to run.

The SQL statement to run.

The name of the database.

The name of the database.

The name of the database schema.

Currently, the schema parameter isn't supported.

The name of the database schema.

Currently, the schema parameter isn't supported.

Appends an item to parameters.

To override the contents of this collection use set_parameters.

The parameters for the SQL statement.

Array parameters are not supported.

The parameters for the SQL statement.

Array parameters are not supported.

The identifier of a transaction that was started by using the BeginTransaction operation. Specify the transaction ID of the transaction that you want to include the SQL statement in.

If the SQL statement is not part of a transaction, don't set this parameter.

The identifier of a transaction that was started by using the BeginTransaction operation. Specify the transaction ID of the transaction that you want to include the SQL statement in.

If the SQL statement is not part of a transaction, don't set this parameter.

A value that indicates whether to include metadata in the results.

A value that indicates whether to include metadata in the results.

A value that indicates whether to continue running the statement after the call times out. By default, the statement stops running when the call times out.

For DDL statements, we recommend continuing to run the statement after the call times out. When a DDL statement terminates before it is finished running, it can result in errors and possibly corrupted data structures.

A value that indicates whether to continue running the statement after the call times out. By default, the statement stops running when the call times out.

For DDL statements, we recommend continuing to run the statement after the call times out. When a DDL statement terminates before it is finished running, it can result in errors and possibly corrupted data structures.

Options that control how the result set is returned.

Options that control how the result set is returned.