Struct aws_sdk_rdsdata::client::fluent_builders::RollbackTransaction [−][src]
pub struct RollbackTransaction<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to RollbackTransaction.
Performs a rollback of a transaction. Rolling back a transaction cancels its changes.
Implementations
impl<C, M, R> RollbackTransaction<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> RollbackTransaction<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<RollbackTransactionOutput, SdkError<RollbackTransactionError>> where
R::Policy: SmithyRetryPolicy<RollbackTransactionInputOperationOutputAlias, RollbackTransactionOutput, RollbackTransactionError, RollbackTransactionInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<RollbackTransactionOutput, SdkError<RollbackTransactionError>> where
R::Policy: SmithyRetryPolicy<RollbackTransactionInputOperationOutputAlias, RollbackTransactionOutput, RollbackTransactionError, RollbackTransactionInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The name or ARN of the secret that enables access to the DB cluster.
The name or ARN of the secret that enables access to the DB cluster.
The identifier of the transaction to roll back.
The identifier of the transaction to roll back.