Module aws_sdk_rdsdata::error[][src]

Errors that can occur when calling the service.

Modules

Structs

There is an error in the call or in a SQL statement.

Error type for the BatchExecuteStatement operation.

Error type for the BeginTransaction operation.

Error type for the CommitTransaction operation.

Error type for the ExecuteSql operation.

Error type for the ExecuteStatement operation.

There are insufficient privileges to make the call.

An internal error occurred.

The resourceArn, secretArn, or transactionId value can't be found.

Error type for the RollbackTransaction operation.

The service specified by the resourceArn parameter is not

The execution of the SQL statement timed out.

Enums

Types of errors that can occur for the BatchExecuteStatement operation.

Types of errors that can occur for the BeginTransaction operation.

Types of errors that can occur for the CommitTransaction operation.

Types of errors that can occur for the ExecuteSql operation.

Types of errors that can occur for the ExecuteStatement operation.

Types of errors that can occur for the RollbackTransaction operation.