Enum aws_sdk_rdsdata::error::BatchExecuteStatementErrorKind[][src]

#[non_exhaustive]
pub enum BatchExecuteStatementErrorKind {
    BadRequestException(BadRequestException),
    ForbiddenException(ForbiddenException),
    InternalServerErrorException(InternalServerErrorException),
    ServiceUnavailableError(ServiceUnavailableError),
    StatementTimeoutException(StatementTimeoutException),
    Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the BatchExecuteStatement operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

BadRequestException(BadRequestException)

Tuple Fields

There is an error in the call or in a SQL statement.

ForbiddenException(ForbiddenException)

Tuple Fields

There are insufficient privileges to make the call.

InternalServerErrorException(InternalServerErrorException)

An internal error occurred.

ServiceUnavailableError(ServiceUnavailableError)

Tuple Fields

The service specified by the resourceArn parameter is not available.

StatementTimeoutException(StatementTimeoutException)

The execution of the SQL statement timed out.

Unhandled(Box<dyn Error + Send + Sync + 'static>)

Tuple Fields

0: Box<dyn Error + Send + Sync + 'static>

An unexpected error, e.g. invalid JSON returned by the service or an unknown error code