Enum aws_sdk_rdsdata::error::CommitTransactionErrorKind [−][src]
#[non_exhaustive]
pub enum CommitTransactionErrorKind {
BadRequestException(BadRequestException),
ForbiddenException(ForbiddenException),
InternalServerErrorException(InternalServerErrorException),
NotFoundException(NotFoundException),
ServiceUnavailableError(ServiceUnavailableError),
StatementTimeoutException(StatementTimeoutException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the CommitTransaction operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BadRequestException(BadRequestException)
Tuple Fields
There is an error in the call or in a SQL statement.
ForbiddenException(ForbiddenException)
Tuple Fields
There are insufficient privileges to make the call.
InternalServerErrorException(InternalServerErrorException)
Tuple Fields
An internal error occurred.
NotFoundException(NotFoundException)
Tuple Fields
The resourceArn, secretArn, or transactionId value can't be found.
ServiceUnavailableError(ServiceUnavailableError)
The service specified by the resourceArn parameter is not
available.
StatementTimeoutException(StatementTimeoutException)
Tuple Fields
The execution of the SQL statement timed out.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code