Struct aws_sdk_rdsdata::input::batch_execute_statement_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for BatchExecuteStatementInput
Implementations
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The name or ARN of the secret that enables access to the DB cluster.
The name or ARN of the secret that enables access to the DB cluster.
The name of the database.
The name of the database schema.
Appends an item to parameter_sets.
To override the contents of this collection use set_parameter_sets.
The parameter set for the batch operation.
The SQL statement is executed as many times as the number of parameter sets provided. To execute a SQL statement with no parameters, use one of the following options:
-
Specify one or more empty parameter sets.
-
Use the
ExecuteStatementoperation instead of theBatchExecuteStatementoperation.
Array parameters are not supported.
The parameter set for the batch operation.
The SQL statement is executed as many times as the number of parameter sets provided. To execute a SQL statement with no parameters, use one of the following options:
-
Specify one or more empty parameter sets.
-
Use the
ExecuteStatementoperation instead of theBatchExecuteStatementoperation.
Array parameters are not supported.
The identifier of a transaction that was started by using the
BeginTransaction operation. Specify the transaction ID of the
transaction that you want to include the SQL statement in.
If the SQL statement is not part of a transaction, don't set this parameter.
The identifier of a transaction that was started by using the
BeginTransaction operation. Specify the transaction ID of the
transaction that you want to include the SQL statement in.
If the SQL statement is not part of a transaction, don't set this parameter.
Consumes the builder and constructs a BatchExecuteStatementInput