Struct aws_sdk_rdsdata::input::commit_transaction_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CommitTransactionInput
Implementations
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The name or ARN of the secret that enables access to the DB cluster.
The name or ARN of the secret that enables access to the DB cluster.
The identifier of the transaction to end and commit.
The identifier of the transaction to end and commit.
Consumes the builder and constructs a CommitTransactionInput