Struct aws_sdk_rdsdata::input::execute_sql_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ExecuteSqlInput
Implementations
The ARN of the Aurora Serverless DB cluster.
The ARN of the Aurora Serverless DB cluster.
The Amazon Resource Name (ARN) of the secret that enables access to the DB cluster.
The Amazon Resource Name (ARN) of the secret that enables access to the DB cluster.
One or more SQL statements to run on the DB cluster.
You can separate SQL statements from each other with a semicolon (;). Any valid SQL statement is permitted, including data definition, data manipulation, and commit statements.
One or more SQL statements to run on the DB cluster.
You can separate SQL statements from each other with a semicolon (;). Any valid SQL statement is permitted, including data definition, data manipulation, and commit statements.
The name of the database.
The name of the database schema.
Consumes the builder and constructs a ExecuteSqlInput