Struct aws_sdk_rdsdata::input::BatchExecuteStatementInput [−][src]
#[non_exhaustive]pub struct BatchExecuteStatementInput {
pub resource_arn: Option<String>,
pub secret_arn: Option<String>,
pub sql: Option<String>,
pub database: Option<String>,
pub schema: Option<String>,
pub parameter_sets: Option<Vec<Vec<SqlParameter>>>,
pub transaction_id: Option<String>,
}Expand description
The request parameters represent the input of a SQL statement over an array of data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_arn: Option<String>The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
secret_arn: Option<String>The name or ARN of the secret that enables access to the DB cluster.
sql: Option<String>The SQL statement to run.
database: Option<String>The name of the database.
schema: Option<String>The name of the database schema.
parameter_sets: Option<Vec<Vec<SqlParameter>>>The parameter set for the batch operation.
The SQL statement is executed as many times as the number of parameter sets provided. To execute a SQL statement with no parameters, use one of the following options:
-
Specify one or more empty parameter sets.
-
Use the
ExecuteStatementoperation instead of theBatchExecuteStatementoperation.
Array parameters are not supported.
transaction_id: Option<String>The identifier of a transaction that was started by using the
BeginTransaction operation. Specify the transaction ID of the
transaction that you want to include the SQL statement in.
If the SQL statement is not part of a transaction, don't set this parameter.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<BatchExecuteStatement, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<BatchExecuteStatement, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<BatchExecuteStatement>
Creates a new builder-style object to manufacture BatchExecuteStatementInput
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The name or ARN of the secret that enables access to the DB cluster.
The parameter set for the batch operation.
The SQL statement is executed as many times as the number of parameter sets provided. To execute a SQL statement with no parameters, use one of the following options:
-
Specify one or more empty parameter sets.
-
Use the
ExecuteStatementoperation instead of theBatchExecuteStatementoperation.
Array parameters are not supported.
The identifier of a transaction that was started by using the
BeginTransaction operation. Specify the transaction ID of the
transaction that you want to include the SQL statement in.
If the SQL statement is not part of a transaction, don't set this parameter.