Struct aws_sdk_rdsdata::input::BeginTransactionInput [−][src]
#[non_exhaustive]pub struct BeginTransactionInput {
pub resource_arn: Option<String>,
pub secret_arn: Option<String>,
pub database: Option<String>,
pub schema: Option<String>,
}Expand description
The request parameters represent the input of a request to start a SQL transaction.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_arn: Option<String>The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
secret_arn: Option<String>The name or ARN of the secret that enables access to the DB cluster.
database: Option<String>The name of the database.
schema: Option<String>The name of the database schema.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<BeginTransaction, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<BeginTransaction, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<BeginTransaction>
Creates a new builder-style object to manufacture BeginTransactionInput
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The name or ARN of the secret that enables access to the DB cluster.