Struct aws_sdk_rdsdata::input::CommitTransactionInput [−][src]
#[non_exhaustive]pub struct CommitTransactionInput {
pub resource_arn: Option<String>,
pub secret_arn: Option<String>,
pub transaction_id: Option<String>,
}Expand description
The request parameters represent the input of a commit transaction request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_arn: Option<String>The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
secret_arn: Option<String>The name or ARN of the secret that enables access to the DB cluster.
transaction_id: Option<String>The identifier of the transaction to end and commit.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CommitTransaction, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CommitTransaction, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<CommitTransaction>
Creates a new builder-style object to manufacture CommitTransactionInput
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The name or ARN of the secret that enables access to the DB cluster.
The identifier of the transaction to end and commit.