Struct aws_sdk_rdsdata::input::ExecuteStatementInput [−][src]
#[non_exhaustive]pub struct ExecuteStatementInput {
pub resource_arn: Option<String>,
pub secret_arn: Option<String>,
pub sql: Option<String>,
pub database: Option<String>,
pub schema: Option<String>,
pub parameters: Option<Vec<SqlParameter>>,
pub transaction_id: Option<String>,
pub include_result_metadata: bool,
pub continue_after_timeout: bool,
pub result_set_options: Option<ResultSetOptions>,
}Expand description
The request parameters represent the input of a request to run a SQL statement against a database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_arn: Option<String>The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
secret_arn: Option<String>The name or ARN of the secret that enables access to the DB cluster.
sql: Option<String>The SQL statement to run.
database: Option<String>The name of the database.
schema: Option<String>The name of the database schema.
Currently, the schema parameter isn't supported.
parameters: Option<Vec<SqlParameter>>The parameters for the SQL statement.
Array parameters are not supported.
transaction_id: Option<String>The identifier of a transaction that was started by using the
BeginTransaction operation. Specify the transaction ID of the
transaction that you want to include the SQL statement in.
If the SQL statement is not part of a transaction, don't set this parameter.
include_result_metadata: boolA value that indicates whether to include metadata in the results.
continue_after_timeout: boolA value that indicates whether to continue running the statement after the call times out. By default, the statement stops running when the call times out.
For DDL statements, we recommend continuing to run the statement after the call times out. When a DDL statement terminates before it is finished running, it can result in errors and possibly corrupted data structures.
result_set_options: Option<ResultSetOptions>Options that control how the result set is returned.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ExecuteStatement, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ExecuteStatement, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ExecuteStatement>
Creates a new builder-style object to manufacture ExecuteStatementInput
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The name or ARN of the secret that enables access to the DB cluster.
The name of the database schema.
Currently, the schema parameter isn't supported.
The parameters for the SQL statement.
Array parameters are not supported.
The identifier of a transaction that was started by using the
BeginTransaction operation. Specify the transaction ID of the
transaction that you want to include the SQL statement in.
If the SQL statement is not part of a transaction, don't set this parameter.
A value that indicates whether to include metadata in the results.
A value that indicates whether to continue running the statement after the call times out. By default, the statement stops running when the call times out.
For DDL statements, we recommend continuing to run the statement after the call times out. When a DDL statement terminates before it is finished running, it can result in errors and possibly corrupted data structures.
Options that control how the result set is returned.