Struct aws_sdk_rdsdata::input::RollbackTransactionInput [−][src]
#[non_exhaustive]pub struct RollbackTransactionInput {
pub resource_arn: Option<String>,
pub secret_arn: Option<String>,
pub transaction_id: Option<String>,
}Expand description
The request parameters represent the input of a request to perform a rollback of a transaction.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_arn: Option<String>The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
secret_arn: Option<String>The name or ARN of the secret that enables access to the DB cluster.
transaction_id: Option<String>The identifier of the transaction to roll back.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<RollbackTransaction, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<RollbackTransaction, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<RollbackTransaction>
Creates a new builder-style object to manufacture RollbackTransactionInput
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The name or ARN of the secret that enables access to the DB cluster.
The identifier of the transaction to roll back.