Enum aws_sdk_rdsdata::model::ArrayValue [−][src]
#[non_exhaustive]
pub enum ArrayValue {
ArrayValues(Vec<ArrayValue>),
BooleanValues(Vec<bool>),
DoubleValues(Vec<f64>),
LongValues(Vec<i64>),
StringValues(Vec<String>),
Unknown,
}Expand description
Contains an array.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ArrayValues(Vec<ArrayValue>)An array of arrays.
Tuple Fields of ArrayValues
0: Vec<ArrayValue>An array of Boolean values.
An array of integers.
An array of floating point numbers.
An array of strings.
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
This variant is marked as non-exhaustive
Implementations
Tries to convert the enum instance into ArrayValues, extracting the inner Vec.
Returns Err(&Self) if it can’t be converted.
Returns true if this is a ArrayValues.
Tries to convert the enum instance into BooleanValues, extracting the inner Vec.
Returns Err(&Self) if it can’t be converted.
Returns true if this is a BooleanValues.
Tries to convert the enum instance into DoubleValues, extracting the inner Vec.
Returns Err(&Self) if it can’t be converted.
Returns true if this is a DoubleValues.
Tries to convert the enum instance into LongValues, extracting the inner Vec.
Returns Err(&Self) if it can’t be converted.
Returns true if this is a LongValues.
Tries to convert the enum instance into StringValues, extracting the inner Vec.
Returns Err(&Self) if it can’t be converted.
Returns true if this is a StringValues.
Returns true if the enum instance is the Unknown variant.