Enum aws_sdk_rdsdata::model::Field [−][src]
#[non_exhaustive]
pub enum Field {
ArrayValue(ArrayValue),
BlobValue(Blob),
BooleanValue(bool),
DoubleValue(f64),
IsNull(bool),
LongValue(i64),
StringValue(String),
Unknown,
}Expand description
Contains a value.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ArrayValue(ArrayValue)
Tuple Fields
0: ArrayValueAn array of values.
BlobValue(Blob)
Tuple Fields
0: BlobA value of BLOB data type.
BooleanValue(bool)
Tuple Fields
0: boolA value of Boolean data type.
DoubleValue(f64)
Tuple Fields
0: f64A value of double data type.
IsNull(bool)
Tuple Fields
0: boolA NULL value.
LongValue(i64)
Tuple Fields
0: i64A value of long data type.
StringValue(String)
Tuple Fields
0: StringA value of string data type.
Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Tries to convert the enum instance into ArrayValue, extracting the inner ArrayValue.
Returns Err(&Self) if it can’t be converted.
Returns true if this is a ArrayValue.
Returns true if this is a BlobValue.
Tries to convert the enum instance into BooleanValue, extracting the inner bool.
Returns Err(&Self) if it can’t be converted.
Returns true if this is a BooleanValue.
Tries to convert the enum instance into DoubleValue, extracting the inner f64.
Returns Err(&Self) if it can’t be converted.
Returns true if this is a DoubleValue.
Returns true if this is a IsNull.
Returns true if this is a LongValue.
Tries to convert the enum instance into StringValue, extracting the inner String.
Returns Err(&Self) if it can’t be converted.
Returns true if this is a StringValue.
Returns true if the enum instance is the Unknown variant.