Enum aws_sdk_rdsdata::model::Value[][src]

#[non_exhaustive]
pub enum Value {
    ArrayValues(Vec<Value>),
    BigIntValue(i64),
    BitValue(bool),
    BlobValue(Blob),
    DoubleValue(f64),
    IntValue(i32),
    IsNull(bool),
    RealValue(f32),
    StringValue(String),
    StructValue(StructValue),
    Unknown,
}
Contains the value of a column.

This data type is deprecated.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

ArrayValues(Vec<Value>)

Tuple Fields

0: Vec<Value>

An array of column values.

BigIntValue(i64)

Tuple Fields

0: i64

A value for a column of big integer data type.

BitValue(bool)

Tuple Fields

0: bool

A value for a column of BIT data type.

BlobValue(Blob)

Tuple Fields

0: Blob

A value for a column of BLOB data type.

DoubleValue(f64)

Tuple Fields

0: f64

A value for a column of double data type.

IntValue(i32)

Tuple Fields

0: i32

A value for a column of integer data type.

IsNull(bool)

Tuple Fields

0: bool

A NULL value.

RealValue(f32)

Tuple Fields

0: f32

A value for a column of real data type.

StringValue(String)

Tuple Fields

0: String

A value for a column of string data type.

StructValue(StructValue)

Tuple Fields

A value for a column of STRUCT data type.

Unknown

The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version. An unknown enum variant

Note: If you encounter this error, consider upgrading your SDK to the latest version. The Unknown variant represents cases where the server sent a value that wasn’t recognized by the client. This can happen when the server adds new functionality, but the client has not been updated. To investigate this, consider turning on debug logging to print the raw HTTP response.

Implementations

Tries to convert the enum instance into ArrayValues, extracting the inner Vec. Returns Err(&Self) if it can’t be converted.

Returns true if this is a ArrayValues.

Tries to convert the enum instance into BigIntValue, extracting the inner i64. Returns Err(&Self) if it can’t be converted.

Returns true if this is a BigIntValue.

Tries to convert the enum instance into BitValue, extracting the inner bool. Returns Err(&Self) if it can’t be converted.

Returns true if this is a BitValue.

Tries to convert the enum instance into BlobValue, extracting the inner Blob. Returns Err(&Self) if it can’t be converted.

Returns true if this is a BlobValue.

Tries to convert the enum instance into DoubleValue, extracting the inner f64. Returns Err(&Self) if it can’t be converted.

Returns true if this is a DoubleValue.

Tries to convert the enum instance into IntValue, extracting the inner i32. Returns Err(&Self) if it can’t be converted.

Returns true if this is a IntValue.

Tries to convert the enum instance into IsNull, extracting the inner bool. Returns Err(&Self) if it can’t be converted.

Returns true if this is a IsNull.

Tries to convert the enum instance into RealValue, extracting the inner f32. Returns Err(&Self) if it can’t be converted.

Returns true if this is a RealValue.

Tries to convert the enum instance into StringValue, extracting the inner String. Returns Err(&Self) if it can’t be converted.

Returns true if this is a StringValue.

Tries to convert the enum instance into StructValue, extracting the inner StructValue. Returns Err(&Self) if it can’t be converted.

Returns true if this is a StructValue.

Returns true if the enum instance is the Unknown variant.