Struct aws_sdk_rdsdata::model::ColumnMetadata [−][src]
#[non_exhaustive]pub struct ColumnMetadata {Show 14 fields
pub name: Option<String>,
pub type: i32,
pub type_name: Option<String>,
pub label: Option<String>,
pub schema_name: Option<String>,
pub table_name: Option<String>,
pub is_auto_increment: bool,
pub is_signed: bool,
pub is_currency: bool,
pub is_case_sensitive: bool,
pub nullable: i32,
pub precision: i32,
pub scale: i32,
pub array_base_column_type: i32,
}Expand description
Contains the metadata for a column.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the column.
type: i32The type of the column.
type_name: Option<String>The database-specific data type of the column.
label: Option<String>The label for the column.
schema_name: Option<String>The name of the schema that owns the table that includes the column.
table_name: Option<String>The name of the table that includes the column.
is_auto_increment: boolA value that indicates whether the column increments automatically.
is_signed: boolA value that indicates whether an integer column is signed.
is_currency: boolA value that indicates whether the column contains currency values.
is_case_sensitive: boolA value that indicates whether the column is case-sensitive.
nullable: i32A value that indicates whether the column is nullable.
precision: i32The precision value of a decimal number column.
scale: i32The scale value of a decimal number column.
array_base_column_type: i32The type of the column.
Implementations
The name of the schema that owns the table that includes the column.
The name of the table that includes the column.
A value that indicates whether the column increments automatically.
A value that indicates whether the column contains currency values.
A value that indicates whether the column is case-sensitive.
The type of the column.
Creates a new builder-style object to manufacture ColumnMetadata