Struct aws_sdk_rdsdata::model::ResultSetMetadata [−][src]
#[non_exhaustive]pub struct ResultSetMetadata {
pub column_count: i64,
pub column_metadata: Option<Vec<ColumnMetadata>>,
}Expand description
The metadata of the result set returned by a SQL statement.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.column_count: i64The number of columns in the result set.
column_metadata: Option<Vec<ColumnMetadata>>The metadata of the columns in the result set.
Implementations
Creates a new builder-style object to manufacture ResultSetMetadata