Struct aws_sdk_rdsdata::model::ResultSetOptions [−][src]
#[non_exhaustive]pub struct ResultSetOptions {
pub decimal_return_type: Option<DecimalReturnType>,
}Expand description
Options that control how the result set is returned.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.decimal_return_type: Option<DecimalReturnType>A value that indicates how a field of DECIMAL type is represented
in the response. The value of STRING, the default, specifies that
it is converted to a String value. The value of DOUBLE_OR_LONG
specifies that it is converted to a Long value if its scale is 0, or to a Double
value otherwise.
Conversion to Double or Long can result in roundoff errors due to precision loss. We recommend converting to String, especially when working with currency values.
Implementations
Creates a new builder-style object to manufacture ResultSetOptions