#[non_exhaustive]pub struct BeginTransactionInputBuilder { /* private fields */ }Expand description
A builder for BeginTransactionInput.
Implementations
Sourceimpl BeginTransactionInputBuilder
impl BeginTransactionInputBuilder
Sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
This field is required.Sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
Sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
Sourcepub fn secret_arn(self, input: impl Into<String>) -> Self
pub fn secret_arn(self, input: impl Into<String>) -> Self
The name or ARN of the secret that enables access to the DB cluster.
This field is required.Sourcepub fn set_secret_arn(self, input: Option<String>) -> Self
pub fn set_secret_arn(self, input: Option<String>) -> Self
The name or ARN of the secret that enables access to the DB cluster.
Sourcepub fn get_secret_arn(&self) -> &Option<String>
pub fn get_secret_arn(&self) -> &Option<String>
The name or ARN of the secret that enables access to the DB cluster.
Sourcepub fn set_database(self, input: Option<String>) -> Self
pub fn set_database(self, input: Option<String>) -> Self
The name of the database.
Sourcepub fn get_database(&self) -> &Option<String>
pub fn get_database(&self) -> &Option<String>
The name of the database.
Sourcepub fn set_schema(self, input: Option<String>) -> Self
pub fn set_schema(self, input: Option<String>) -> Self
The name of the database schema.
Sourcepub fn get_schema(&self) -> &Option<String>
pub fn get_schema(&self) -> &Option<String>
The name of the database schema.
Sourcepub fn build(self) -> Result<BeginTransactionInput, BuildError>
pub fn build(self) -> Result<BeginTransactionInput, BuildError>
Consumes the builder and constructs a BeginTransactionInput.
Sourceimpl BeginTransactionInputBuilder
impl BeginTransactionInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BeginTransactionOutput, SdkError<BeginTransactionError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BeginTransactionOutput, SdkError<BeginTransactionError, HttpResponse>>
Sends a request with this input using the given client.