Enum aws_sdk_rdsdata::error::BatchExecuteStatementErrorKind [−][src]
#[non_exhaustive]
pub enum BatchExecuteStatementErrorKind {
BadRequestException(BadRequestException),
ForbiddenException(ForbiddenException),
InternalServerErrorException(InternalServerErrorException),
ServiceUnavailableError(ServiceUnavailableError),
StatementTimeoutException(StatementTimeoutException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the BatchExecuteStatement operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BadRequestException(BadRequestException)There is an error in the call or in a SQL statement.
Tuple Fields of BadRequestException
ForbiddenException(ForbiddenException)There are insufficient privileges to make the call.
Tuple Fields of ForbiddenException
InternalServerErrorException(InternalServerErrorException)An internal error occurred.
Tuple Fields of InternalServerErrorException
The service specified by the resourceArn parameter is not
available.
StatementTimeoutException(StatementTimeoutException)The execution of the SQL statement timed out.
Tuple Fields of StatementTimeoutException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code