Enum aws_sdk_rdsdata::error::CommitTransactionErrorKind[][src]

#[non_exhaustive]
pub enum CommitTransactionErrorKind {
    BadRequestException(BadRequestException),
    ForbiddenException(ForbiddenException),
    InternalServerErrorException(InternalServerErrorException),
    NotFoundException(NotFoundException),
    ServiceUnavailableError(ServiceUnavailableError),
    StatementTimeoutException(StatementTimeoutException),
    Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the CommitTransaction operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BadRequestException(BadRequestException)

There is an error in the call or in a SQL statement.

Tuple Fields of BadRequestException

0: BadRequestException
ForbiddenException(ForbiddenException)

There are insufficient privileges to make the call.

Tuple Fields of ForbiddenException

0: ForbiddenException
InternalServerErrorException(InternalServerErrorException)

An internal error occurred.

Tuple Fields of InternalServerErrorException

0: InternalServerErrorException
NotFoundException(NotFoundException)

The resourceArn, secretArn, or transactionId value can't be found.

Tuple Fields of NotFoundException

0: NotFoundException
ServiceUnavailableError(ServiceUnavailableError)

The service specified by the resourceArn parameter is not available.

Tuple Fields of ServiceUnavailableError

0: ServiceUnavailableError
StatementTimeoutException(StatementTimeoutException)

The execution of the SQL statement timed out.

Tuple Fields of StatementTimeoutException

0: StatementTimeoutException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, eg. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>