Struct aws_sdk_rdsdata::input::ExecuteSqlInput [−][src]
#[non_exhaustive]pub struct ExecuteSqlInput {
pub db_cluster_or_instance_arn: Option<String>,
pub aws_secret_store_arn: Option<String>,
pub sql_statements: Option<String>,
pub database: Option<String>,
pub schema: Option<String>,
}Expand description
The request parameters represent the input of a request to run one or more SQL statements.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.db_cluster_or_instance_arn: Option<String>The ARN of the Aurora Serverless DB cluster.
aws_secret_store_arn: Option<String>The Amazon Resource Name (ARN) of the secret that enables access to the DB cluster.
sql_statements: Option<String>One or more SQL statements to run on the DB cluster.
You can separate SQL statements from each other with a semicolon (;). Any valid SQL statement is permitted, including data definition, data manipulation, and commit statements.
database: Option<String>The name of the database.
schema: Option<String>The name of the database schema.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ExecuteSql, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ExecuteSql, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ExecuteSql>
Creates a new builder-style object to manufacture ExecuteSqlInput