Enum aws_sdk_rdsdata::model::ArrayValue [−][src]
#[non_exhaustive]
pub enum ArrayValue {
ArrayValues(Vec<ArrayValue>),
BooleanValues(Vec<bool>),
DoubleValues(Vec<f64>),
LongValues(Vec<i64>),
StringValues(Vec<String>),
}Expand description
Contains an array.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ArrayValues(Vec<ArrayValue>)An array of arrays.
Tuple Fields of ArrayValues
0: Vec<ArrayValue>An array of Boolean values.
An array of integers.
An array of floating point numbers.
An array of strings.
Implementations
Tries to convert the enum instance into its ArrayValue variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the ArrayValue variant.
Tries to convert the enum instance into its ArrayValue variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the ArrayValue variant.
Tries to convert the enum instance into its ArrayValue variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the ArrayValue variant.
Tries to convert the enum instance into its ArrayValue variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the ArrayValue variant.
Tries to convert the enum instance into its ArrayValue variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the ArrayValue variant.