Enum aws_sdk_rdsdata::model::Field [−][src]
#[non_exhaustive]
pub enum Field {
ArrayValue(ArrayValue),
BlobValue(Blob),
BooleanValue(bool),
DoubleValue(f64),
IsNull(bool),
LongValue(i64),
StringValue(String),
}Expand description
Contains a value.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ArrayValue(ArrayValue)An array of values.
Tuple Fields of ArrayValue
0: ArrayValueBlobValue(Blob)A value of BLOB data type.
Tuple Fields of BlobValue
0: BlobBooleanValue(bool)A value of Boolean data type.
Tuple Fields of BooleanValue
0: boolDoubleValue(f64)A value of double data type.
Tuple Fields of DoubleValue
0: f64IsNull(bool)A NULL value.
Tuple Fields of IsNull
0: boolLongValue(i64)A value of long data type.
Tuple Fields of LongValue
0: i64StringValue(String)A value of string data type.
Tuple Fields of StringValue
0: StringImplementations
Tries to convert the enum instance into its Field variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Field variant.
Tries to convert the enum instance into its Field variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Field variant.
Tries to convert the enum instance into its Field variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Field variant.
Tries to convert the enum instance into its Field variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Field variant.
Tries to convert the enum instance into its Field variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Field variant.
Tries to convert the enum instance into its Field variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Field variant.
Tries to convert the enum instance into its Field variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Field variant.