Enum aws_sdk_rdsdata::model::Value[][src]

#[non_exhaustive]
pub enum Value {
    ArrayValues(Vec<Value>),
    BigIntValue(i64),
    BitValue(bool),
    BlobValue(Blob),
    DoubleValue(f64),
    IntValue(i32),
    IsNull(bool),
    RealValue(f32),
    StringValue(String),
    StructValue(StructValue),
}
Contains the value of a column.

This data type is deprecated.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ArrayValues(Vec<Value>)

An array of column values.

Tuple Fields of ArrayValues

0: Vec<Value>
BigIntValue(i64)

A value for a column of big integer data type.

Tuple Fields of BigIntValue

0: i64
BitValue(bool)

A value for a column of BIT data type.

Tuple Fields of BitValue

0: bool
BlobValue(Blob)

A value for a column of BLOB data type.

Tuple Fields of BlobValue

0: Blob
DoubleValue(f64)

A value for a column of double data type.

Tuple Fields of DoubleValue

0: f64
IntValue(i32)

A value for a column of integer data type.

Tuple Fields of IntValue

0: i32
IsNull(bool)

A NULL value.

Tuple Fields of IsNull

0: bool
RealValue(f32)

A value for a column of real data type.

Tuple Fields of RealValue

0: f32
StringValue(String)

A value for a column of string data type.

Tuple Fields of StringValue

0: String
StructValue(StructValue)

A value for a column of STRUCT data type.

Tuple Fields of StructValue

0: StructValue

Implementations

Tries to convert the enum instance into its Value variant. Returns Err(&Self) if it can't be converted.

Returns true if the enum instance is the Value variant.

Tries to convert the enum instance into its Value variant. Returns Err(&Self) if it can't be converted.

Returns true if the enum instance is the Value variant.

Tries to convert the enum instance into its Value variant. Returns Err(&Self) if it can't be converted.

Returns true if the enum instance is the Value variant.

Tries to convert the enum instance into its Value variant. Returns Err(&Self) if it can't be converted.

Returns true if the enum instance is the Value variant.

Tries to convert the enum instance into its Value variant. Returns Err(&Self) if it can't be converted.

Returns true if the enum instance is the Value variant.

Tries to convert the enum instance into its Value variant. Returns Err(&Self) if it can't be converted.

Returns true if the enum instance is the Value variant.

Tries to convert the enum instance into its Value variant. Returns Err(&Self) if it can't be converted.

Returns true if the enum instance is the Value variant.

Tries to convert the enum instance into its Value variant. Returns Err(&Self) if it can't be converted.

Returns true if the enum instance is the Value variant.

Tries to convert the enum instance into its Value variant. Returns Err(&Self) if it can't be converted.

Returns true if the enum instance is the Value variant.

Tries to convert the enum instance into its Value variant. Returns Err(&Self) if it can't be converted.

Returns true if the enum instance is the Value variant.