Enum aws_sdk_rdsdata::model::Value [−][src]
#[non_exhaustive]
pub enum Value {
ArrayValues(Vec<Value>),
BigIntValue(i64),
BitValue(bool),
BlobValue(Blob),
DoubleValue(f64),
IntValue(i32),
IsNull(bool),
RealValue(f32),
StringValue(String),
StructValue(StructValue),
}Expand description
Contains the value of a column.
This data type is deprecated.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
An array of column values.
BigIntValue(i64)A value for a column of big integer data type.
Tuple Fields of BigIntValue
0: i64BitValue(bool)A value for a column of BIT data type.
Tuple Fields of BitValue
0: boolBlobValue(Blob)A value for a column of BLOB data type.
Tuple Fields of BlobValue
0: BlobDoubleValue(f64)A value for a column of double data type.
Tuple Fields of DoubleValue
0: f64IntValue(i32)A value for a column of integer data type.
Tuple Fields of IntValue
0: i32IsNull(bool)A NULL value.
Tuple Fields of IsNull
0: boolRealValue(f32)A value for a column of real data type.
Tuple Fields of RealValue
0: f32StringValue(String)A value for a column of string data type.
Tuple Fields of StringValue
0: StringStructValue(StructValue)A value for a column of STRUCT data type.
Tuple Fields of StructValue
0: StructValueImplementations
Tries to convert the enum instance into its Value variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Value variant.
Tries to convert the enum instance into its Value variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Value variant.
Tries to convert the enum instance into its Value variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Value variant.
Tries to convert the enum instance into its Value variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Value variant.
Tries to convert the enum instance into its Value variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Value variant.
Tries to convert the enum instance into its Value variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Value variant.
Tries to convert the enum instance into its Value variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Value variant.
Tries to convert the enum instance into its Value variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Value variant.
Tries to convert the enum instance into its Value variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Value variant.
Tries to convert the enum instance into its Value variant.
Returns Err(&Self) if it can't be converted.
Returns true if the enum instance is the Value variant.