Struct aws_sdk_rdsdata::model::sql_parameter::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for SqlParameter
Implementations
A hint that specifies the correct object type for data type mapping. Possible values are as follows:
-
DATE- The correspondingStringparameter value is sent as an object ofDATEtype to the database. The accepted format isYYYY-MM-DD. -
DECIMAL- The correspondingStringparameter value is sent as an object ofDECIMALtype to the database. -
JSON- The correspondingStringparameter value is sent as an object ofJSONtype to the database. -
TIME- The correspondingStringparameter value is sent as an object ofTIMEtype to the database. The accepted format isHH:MM:SS[.FFF]. -
TIMESTAMP- The correspondingStringparameter value is sent as an object ofTIMESTAMPtype to the database. The accepted format isYYYY-MM-DD HH:MM:SS[.FFF]. -
UUID- The correspondingStringparameter value is sent as an object ofUUIDtype to the database.
A hint that specifies the correct object type for data type mapping. Possible values are as follows:
-
DATE- The correspondingStringparameter value is sent as an object ofDATEtype to the database. The accepted format isYYYY-MM-DD. -
DECIMAL- The correspondingStringparameter value is sent as an object ofDECIMALtype to the database. -
JSON- The correspondingStringparameter value is sent as an object ofJSONtype to the database. -
TIME- The correspondingStringparameter value is sent as an object ofTIMEtype to the database. The accepted format isHH:MM:SS[.FFF]. -
TIMESTAMP- The correspondingStringparameter value is sent as an object ofTIMESTAMPtype to the database. The accepted format isYYYY-MM-DD HH:MM:SS[.FFF]. -
UUID- The correspondingStringparameter value is sent as an object ofUUIDtype to the database.
Consumes the builder and constructs a SqlParameter