Struct aws_sdk_rdsdata::model::ColumnMetadata[][src]

#[non_exhaustive]
pub struct ColumnMetadata {
Show 14 fields pub name: Option<String>, pub type: i32, pub type_name: Option<String>, pub label: Option<String>, pub schema_name: Option<String>, pub table_name: Option<String>, pub is_auto_increment: bool, pub is_signed: bool, pub is_currency: bool, pub is_case_sensitive: bool, pub nullable: i32, pub precision: i32, pub scale: i32, pub array_base_column_type: i32,
}
Contains the metadata for a column.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: Option<String>

The name of the column.

type: i32

The type of the column.

type_name: Option<String>

The database-specific data type of the column.

label: Option<String>

The label for the column.

schema_name: Option<String>

The name of the schema that owns the table that includes the column.

table_name: Option<String>

The name of the table that includes the column.

is_auto_increment: bool

A value that indicates whether the column increments automatically.

is_signed: bool

A value that indicates whether an integer column is signed.

is_currency: bool

A value that indicates whether the column contains currency values.

is_case_sensitive: bool

A value that indicates whether the column is case-sensitive.

nullable: i32

A value that indicates whether the column is nullable.

precision: i32

The precision value of a decimal number column.

scale: i32

The scale value of a decimal number column.

array_base_column_type: i32

The type of the column.

Implementations

Creates a new builder-style object to manufacture ColumnMetadata