Struct aws_sdk_rdsdata::output::execute_statement_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ExecuteStatementOutput
Implementations
Appends an item to records.
To override the contents of this collection use set_records.
The records returned by the SQL statement.
The records returned by the SQL statement.
Appends an item to column_metadata.
To override the contents of this collection use set_column_metadata.
Metadata for the columns included in the results.
Metadata for the columns included in the results.
The number of records updated by the request.
The number of records updated by the request.
Appends an item to generated_fields.
To override the contents of this collection use set_generated_fields.
Values for fields generated during the request.
The generatedFields data isn't supported by Aurora PostgreSQL.
To get the values of generated fields, use the RETURNING clause. For
more information, see Returning Data From
Modified Rows in the PostgreSQL documentation.
Values for fields generated during the request.
The generatedFields data isn't supported by Aurora PostgreSQL.
To get the values of generated fields, use the RETURNING clause. For
more information, see Returning Data From
Modified Rows in the PostgreSQL documentation.
Consumes the builder and constructs a ExecuteStatementOutput