Struct aws_sdk_rdsdata::output::ExecuteStatementOutput [−][src]
#[non_exhaustive]pub struct ExecuteStatementOutput {
pub records: Option<Vec<Vec<Field>>>,
pub column_metadata: Option<Vec<ColumnMetadata>>,
pub number_of_records_updated: i64,
pub generated_fields: Option<Vec<Field>>,
}Expand description
The response elements represent the output of a request to run a SQL statement against a database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.records: Option<Vec<Vec<Field>>>The records returned by the SQL statement.
column_metadata: Option<Vec<ColumnMetadata>>Metadata for the columns included in the results.
number_of_records_updated: i64The number of records updated by the request.
generated_fields: Option<Vec<Field>>Values for fields generated during the request.
The generatedFields data isn't supported by Aurora PostgreSQL.
To get the values of generated fields, use the RETURNING clause. For
more information, see Returning Data From
Modified Rows in the PostgreSQL documentation.
Implementations
Creates a new builder-style object to manufacture ExecuteStatementOutput